// src/main.cc - Copyright 2005, 2006, University
//               of Padova, dept. of Pure and Applied
//               Mathematics
//
// This file is part of SGPEMv2.
//
// This is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// SGPEMv2 is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with SGPEMv2; if not, write to the Free Software
// Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA

#include "config.h"
#include "gettext.h"

#include "main.hh"
#include "parseopts.hh"
#include "startgui.hh"

#include "templates/smartp.hh"
#include "backend/history.hh"
#include "backend/slice.hh"
#include "backend/schedulable.hh"
#include "backend/schedulableStatus.hh"
#include "backend/simulationStatus.hh"
#include "backend/process.hh"

#include <iostream>
#include <string>
#include <vector>

  using namespace std;
  using namespace sgpem;
  using namespace memory;
  
int 
main(int argc, char* argv[]) 
{


  // Set up gettext support
  setlocale(LC_ALL, "");
  bindtextdomain(PACKAGE, LOCALEDIR);
  textdomain(PACKAGE);
  /*
  // Parses options and prepares vector with 
  // filenames of documents to be opened
  vector<string> filenames;
  {
    int a_count  = argc;
    char** a_ptr = argv;
    parse_options(a_count, a_ptr);
    filenames.insert(filenames.begin(), a_ptr, a_ptr+a_count);
  }
  */
//start_gui(argc, argv);
  
  //SMOKE-TEST for backend classes
	cout << "\n\n********************************";  
	Process p1("P1", 0,10,1);
	Process p2("P2", 0,30,2);
	Process p3("P3", 5,15,3);
	
	SchedulableStatus ss1(p1);
	SchedulableStatus ss2(p2);
	SchedulableStatus ss3(p3);
	
	SimulationStatus sim1;	sim1.setRunning(p1);
	SimulationStatus sim2;	sim2.setRunning(p2);
	SimulationStatus sim3;	sim3.setRunning(p3);
		
	History h(History::getInstance());
	
	h.enqueueSlice(sim1);
	h.enqueueSlice(sim1);
			h.enqueueSlice(sim2);
	h.enqueueSlice(sim1);
		h.enqueueSlice(sim2);
	h.enqueueSlice(sim1);
		h.enqueueSlice(sim2);
				h.enqueueSlice(sim3);
				h.enqueueSlice(sim3);
	h.enqueueSlice(sim1);
				h.enqueueSlice(sim3);
	h.enqueueSlice(sim1);
	
	h.truncateAt(3);
	
	smart_ptr<const sgpem::SimulationStatus> quale;
	
	quale = h.getSimulationStatusAt(0);
	if (quale)		cout << "\n" << quale->getRunning()->getSchedulable()->getName(); else cout << "NO";
	quale = h.getSimulationStatusAt(1);
	if (quale)		cout << "\n" << quale->getRunning()->getSchedulable()->getName(); else cout << "NO";
	quale = h.getSimulationStatusAt(2);
	if (quale)		cout << "\n" << quale->getRunning()->getSchedulable()->getName(); else cout << "NO";
	
	h.truncateAt(2);
	
	smart_ptr<const sgpem::SchedulableStatus> quale2;
	quale2 = h.getScheduledAt(0);
	if (quale2)	cout << "\n" << quale2->getSchedulable()->getName(); else cout << "NO";
	quale2 = h.getScheduledAt(1);
	if (quale2)	cout << "\n" << quale2->getSchedulable()->getName(); else cout << "NO";
	quale2 = h.getScheduledAt(2);
	if (quale2)	cout << "\n" << quale2->getSchedulable()->getName(); else cout << "NO";
  
	
	cout << "\n\n";
  return 0;
}
